@@ -55,7 +55,7 @@ def knscore(jd, fid, magpsf, sigmapsf, jdstarthist, cdsxmatch, ndethist, model_n
     model_name: str
         Nome of the model to be fetched from the kndetect package.
         supported options: "complete.pkl", "partial.pkl"
-        deault is "complete.pkl" (model trained for complete light curves)
+        deault is "partial.pkl" (model trained for complete light curves)
 
     Returns
     ----------
@@ -64,14 +64,13 @@ def knscore(jd, fid, magpsf, sigmapsf, jdstarthist, cdsxmatch, ndethist, model_n
 
     Examples
     ----------
-    >>> from fink_science.xmatch.processor import cdsxmatch
+    >>> from fink_science.xmatch.processor import xmatch_cds
     >>> from fink_utils.spark.utils import concat_col
     >>> from pyspark.sql import functions as F
 
     >>> df = spark.read.load(ztf_alert_sample)
 
-    >>> colnames = [df['objectId'], df['candidate.ra'], df['candidate.dec']]
-    >>> df = df.withColumn('cdsxmatch', cdsxmatch(*colnames))
+    >>> df = xmatch_cds(df)
 
     # Required alert columns
     >>> what = ['jd', 'fid', 'magpsf', 'sigmapsf']
@@ -147,7 +146,7 @@ def knscore(jd, fid, magpsf, sigmapsf, jdstarthist, cdsxmatch, ndethist, model_n
 
     # Load pre-trained model
     if model_name is None:
-        model = load_classifier("complete.pkl")
+        model = load_classifier("partial.pkl")
     else:
         model = load_classifier(model_name.values[0])
 
